@@ -39,17 +39,18 @@ _BROWSE_QUERIES = {
 }
 
 _BROWSE_FILTERS = {
-    None: dict(
-        album='track.album = ?',
-        albumartist='album.artists = ?',
-        artist='track.artists = ?',
-        composer='track.composers = ?',
-        date="track.date LIKE ? || '%'",
-        genre='track.genre = ?',
-        performer='track.performers = ?'
-    ),
-    Ref.ARTIST: dict(
-        role={
+    None: {
+        'album': 'track.album = ?',
+        'albumartist': 'album.artists = ?',
+        'artist': 'track.artists = ?',
+        'composer': 'track.composers = ?',
+        'date': "track.date LIKE ? || '%'",
+        'genre': 'track.genre = ?',
+        'performer': 'track.performers = ?',
+        'max-age': "track.last_modified > strftime('%s', 'now') - ?",
+    },
+    Ref.ARTIST: {
+        'role': {
             'albumartist': """EXISTS (
                 SELECT * FROM album WHERE album.artists = artist.uri
             )""",
@@ -63,26 +64,43 @@ _BROWSE_FILTERS = {
                 SELECT * FROM track WHERE track.performers = artist.uri
             )"""
         },
-    ),
-    Ref.ALBUM: dict(
-        albumartist='artists = ?',
-        artist='? IN (SELECT artists FROM track WHERE album = album.uri)',
-        composer='? IN (SELECT composers FROM track WHERE album = album.uri)',
-        date="""EXISTS (
+    },
+    Ref.ALBUM: {
+        'albumartist': 'artists = ?',
+        'artist': """? IN (
+            SELECT artists FROM track WHERE album = album.uri
+        )""",
+        'composer': """? IN (
+            SELECT composers FROM track WHERE album = album.uri
+        )""",
+        'date': """EXISTS (
             SELECT * FROM track WHERE album = album.uri AND date LIKE ? || '%'
         )""",
-        genre='? IN (SELECT genre FROM track WHERE album = album.uri)',
-        performer='? IN (SELECT performers FROM track WHERE album = album.uri)'
-    ),
-    Ref.TRACK: dict(
-        album='album = ?',
-        albumartist='? IN (SELECT artists FROM album WHERE uri = track.album)',
-        artist='artists = ?',
-        composer='composers = ?',
-        date="date LIKE ? || '%'",
-        genre='genre = ?',
-        performer='performers = ?'
-    )
+        'genre': """? IN (
+            SELECT genre FROM track WHERE album = album.uri
+        )""",
+        'performer': """? IN (
+            SELECT performers FROM track WHERE album = album.uri
+        )""",
+        'max-age': """EXISTS (
+            SELECT *
+              FROM track
+             WHERE album = album.uri
+               AND last_modified > strftime('%s', 'now') - ?
+        )""",
+    },
+    Ref.TRACK: {
+        'album': 'album = ?',
+        'albumartist': """? IN (
+            SELECT artists FROM album WHERE uri = track.album
+        )""",
+        'artist': 'artists = ?',
+        'composer': 'composers = ?',
+        'date': "date LIKE ? || '%'",
+        'genre': 'genre = ?',
+        'performer': 'performers = ?',
+        'max-age': "last_modified > strftime('%s', 'now') - ?",
+    }
 }
 
 _SEARCH_SQL = """
@@ -98,9 +116,9 @@ _SEARCH_FILTERS = {
     'composer': 'composer_uri = ?',
     'date': "date LIKE ? || '%'",
     'genre': 'genre = ?',
-    'mtime': "datetime(last_motified, 'unixepoch') LIKE ? || '%'",
     'performer': 'performer_uri = ?',
     'uri': 'uri GLOB ?',
+    'max-age': "last_modified > strftime('%s', 'now') - ?",
 }
 
 _SEARCH_FIELDS = {
@@ -117,7 +135,7 @@ _SEARCH_FIELDS = {
     'comment'
 }
 
-schema_version = 4
+schema_version = 5
 
 logger = logging.getLogger(__name__)
 
@@ -173,14 +191,6 @@ def dates(c, format='%Y-%m-%d'):
     """, [format]))
 
 
-def images(c):
-    return itertools.chain.from_iterable(row[0].split() for row in c.execute("""
-    SELECT DISTINCT images
-      FROM album
-     WHERE images IS NOT NULL
-    """))
-
-
 def lookup(c, uri):
     row = c.execute('SELECT * FROM tracks WHERE uri = ?', [uri]).fetchone()
     if row:
@@ -221,8 +231,10 @@ def search_tracks(c, query, limit, offset, exact, filters=[]):
             logger.debug('Skipped SQLite search filter %r', kwargs)
     if clauses:
         sql += ' AND (%s)' % ' OR '.join(clauses)
+    sql += ' LIMIT ? OFFSET ?'
+    params += [limit, offset]
     logger.debug('SQLite search query %r: %s', params, sql)
-    rows = c.execute(sql + ' LIMIT ? OFFSET ?', params + [limit, offset])
+    rows = c.execute(sql, params)
     return map(_track, rows)
 
 
