@@ -18,6 +18,7 @@ class LocalLibraryProviderTest(unittest.TestCase):
             'timeout': 1.0,
             'use_album_mbid_uri': False,
             'use_artist_mbid_uri': False,
+            'search_limit': None
         }
     }
 
@@ -25,7 +26,8 @@ class LocalLibraryProviderTest(unittest.TestCase):
         self.tempdir = tempfile.mkdtemp()
         self.library = library.SQLiteLibrary(dict(self.config, local={
             'media_dir': self.tempdir,
-            'data_dir': self.tempdir
+            'data_dir': self.tempdir,
+            'excluded_file_extensions': []
         }))
         self.library.load()
 
